@@ -1,4 +1,4 @@
-use std::ops::{Add, Sub};
+use std::ops::Add;
 
 use chrono::{Duration, NaiveTime, Timelike};
 
@@ -6,12 +6,25 @@ use crate::schedule::EventSchedule;
 
 use super::{category::Category, event::EventInstance};
 
-pub struct Meta {
+pub struct MapMeta {
     pub name: String,
     pub category: Category,
     pub schedules: Vec<EventSchedule>,
 }
 
+impl IntoIterator for MapMeta {
+    type Item = EventInstance;
+
+    type IntoIter = IntoIter;
+
+    fn into_iter(self) -> Self::IntoIter {
+        IntoIter {
+            current_time: Duration::zero(),
+            schedules: self.schedules,
+        }
+    }
+}
+
 pub struct IntoIter {
     /// Respresents the amount of time from UTC 00:00
     current_time: Duration,
@@ -21,13 +34,6 @@ pub struct IntoIter {
 }
 
 impl IntoIter {
-    pub fn new<'a>(meta_key: &'a MetaKey, current_time: NaiveTime) -> Self {
-        Self {
-            current_time: Duration::seconds(current_time.num_seconds_from_midnight() as i64),
-            schedules: meta_key.info().schedules,
-        }
-    }
-
     /// Skip to a certain time of day
     pub fn time(mut self, time: NaiveTime) -> Self {
         self.current_time = Duration::seconds(time.num_seconds_from_midnight() as i64);
@@ -35,7 +41,7 @@ impl IntoIter {
     }
 
     /// Skip forward an amount of time
-    pub fn fast_foward(mut self, amount: Duration) -> Self {
+    pub fn fast_forward(mut self, amount: Duration) -> Self {
         self.current_time = self.current_time.add(amount);
         self
     }
@@ -46,7 +52,7 @@ impl IntoIter {
             .filter_map(|event_schedules| {
                 event_schedules
                     .into_iter()
-                    .fast_foward(self.current_time)
+                    .fast_forward(self.current_time)
                     .now()
             })
             .next()
@@ -60,18 +66,14 @@ impl Iterator for IntoIter {
         let next_event: EventInstance = self
             .schedules
             .iter()
-            .map(|event_schedule| {
+            .filter_map(|event_schedule| {
                 event_schedule
                     .into_iter()
-                    .fast_foward(self.current_time)
+                    .fast_forward(self.current_time)
                     .next()
-                    .unwrap()
             })
             .reduce(|event_a, event_b| {
-                let time_until_a = event_a.start_time.sub(self.current_time);
-                let time_until_b = event_b.start_time.sub(self.current_time);
-
-                if time_until_b < time_until_a {
+                if event_b.start_time < event_a.start_time {
                     event_b
                 } else {
                     event_a
@@ -83,17 +85,37 @@ impl Iterator for IntoIter {
     }
 }
 
-impl IntoIterator for MetaKey {
+impl IntoIterator for MapMetaKind {
     type Item = EventInstance;
 
     type IntoIter = IntoIter;
 
     fn into_iter(self) -> Self::IntoIter {
-        IntoIter::new(&self, NaiveTime::from_hms(0, 0, 0))
+        self.info().into_iter()
     }
 }
 
-pub enum MetaKey {
+impl<'a> IntoIterator for &'a MapMetaKind {
+    type Item = EventInstance;
+
+    type IntoIter = IntoIter;
+
+    fn into_iter(self) -> Self::IntoIter {
+        self.info().into_iter()
+    }
+}
+
+impl<'a> IntoIterator for &'a mut MapMetaKind {
+    type Item = EventInstance;
+
+    type IntoIter = IntoIter;
+
+    fn into_iter(self) -> Self::IntoIter {
+        self.info().into_iter()
+    }
+}
+
+pub enum MapMetaKind {
     DayAndNight,
     WorldBosses,
     HardWorldBosses,
@@ -118,37 +140,39 @@ pub enum MetaKey {
     Dragonstorm,
 }
 
-impl MetaKey {
-    pub fn all_keys() -> Vec<MetaKey> {
-        vec![
-            MetaKey::DayAndNight,
-            MetaKey::WorldBosses,
-            MetaKey::HardWorldBosses,
-            MetaKey::LeyLineAnomaly,
-            MetaKey::PVPTournaments,
-            MetaKey::DryTop,
-            MetaKey::VerdantBrink,
-            MetaKey::AuricBasin,
-            MetaKey::TangledDepths,
-            MetaKey::DragonsStand,
-            MetaKey::LakeDoric,
-            MetaKey::CrystalOasis,
-            MetaKey::DesertHighlands,
-            MetaKey::ElonRiverlands,
-            MetaKey::TheDesolation,
-            MetaKey::DomainOfVabbi,
-            MetaKey::DomainOfIstan,
-            MetaKey::JahaiBluffs,
-            MetaKey::ThunderheadPeaks,
-            MetaKey::GrothmarValley,
-            MetaKey::BjoraMarches,
-            MetaKey::Dragonstorm,
+impl MapMetaKind {
+    /// Get all the map meta keys available
+    pub fn all_keys() -> [MapMetaKind; 22] {
+        [
+            MapMetaKind::DayAndNight,
+            MapMetaKind::WorldBosses,
+            MapMetaKind::HardWorldBosses,
+            MapMetaKind::LeyLineAnomaly,
+            MapMetaKind::PVPTournaments,
+            MapMetaKind::DryTop,
+            MapMetaKind::VerdantBrink,
+            MapMetaKind::AuricBasin,
+            MapMetaKind::TangledDepths,
+            MapMetaKind::DragonsStand,
+            MapMetaKind::LakeDoric,
+            MapMetaKind::CrystalOasis,
+            MapMetaKind::DesertHighlands,
+            MapMetaKind::ElonRiverlands,
+            MapMetaKind::TheDesolation,
+            MapMetaKind::DomainOfVabbi,
+            MapMetaKind::DomainOfIstan,
+            MapMetaKind::JahaiBluffs,
+            MapMetaKind::ThunderheadPeaks,
+            MapMetaKind::GrothmarValley,
+            MapMetaKind::BjoraMarches,
+            MapMetaKind::Dragonstorm,
         ]
     }
 
-    pub fn info(&self) -> Meta {
+    /// Get the schedule of this map meta event
+    pub fn info(&self) -> MapMeta {
         match self {
-            MetaKey::DayAndNight => Meta {
+            MapMetaKind::DayAndNight => MapMeta {
                 name: "Day and Night".to_string(),
                 category: Category::CoreTyria,
                 schedules: vec![
@@ -178,7 +202,7 @@ impl MetaKey {
                     },
                 ],
             },
-            MetaKey::WorldBosses => Meta {
+            MapMetaKind::WorldBosses => MapMeta {
                 name: "World Bosses".to_string(),
                 category: Category::CoreTyria,
                 schedules: vec![
@@ -244,7 +268,7 @@ impl MetaKey {
                     },
                 ],
             },
-            MetaKey::HardWorldBosses => Meta {
+            MapMetaKind::HardWorldBosses => MapMeta {
                 name: "Hard World Bosses".to_string(),
                 category: Category::CoreTyria,
                 schedules: vec![
@@ -358,7 +382,7 @@ impl MetaKey {
                     },
                 ],
             },
-            MetaKey::LeyLineAnomaly => Meta {
+            MapMetaKind::LeyLineAnomaly => MapMeta {
                 name: "Ley-Line Anomaly".to_string(),
                 category: Category::CoreTyria,
                 schedules: vec![
@@ -382,7 +406,7 @@ impl MetaKey {
                     },
                 ],
             },
-            MetaKey::PVPTournaments => Meta {
+            MapMetaKind::PVPTournaments => MapMeta {
                 name: "PvP Tournaments".to_string(),
                 category: Category::CoreTyria,
                 schedules: vec![
@@ -412,7 +436,7 @@ impl MetaKey {
                     },
                 ],
             },
-            MetaKey::DryTop => Meta {
+            MapMetaKind::DryTop => MapMeta {
                 name: "Dry Top".to_string(),
                 category: Category::LivingWorldSeason2,
                 schedules: vec![
@@ -430,7 +454,7 @@ impl MetaKey {
                     },
                 ],
             },
-            MetaKey::VerdantBrink => Meta {
+            MapMetaKind::VerdantBrink => MapMeta {
                 name: "Verdant Brink".to_string(),
                 category: Category::HeartOfThorns,
                 schedules: vec![
@@ -454,7 +478,7 @@ impl MetaKey {
                     },
                 ],
             },
-            MetaKey::AuricBasin => Meta {
+            MapMetaKind::AuricBasin => MapMeta {
                 name: "Auric Basin".to_string(),
                 category: Category::HeartOfThorns,
                 schedules: vec![
@@ -478,13 +502,13 @@ impl MetaKey {
                     },
                     EventSchedule {
                         name: "Pylons".to_string(),
-                        offset: NaiveTime::from_hms(1, 10, 0),
+                        offset: NaiveTime::from_hms(1, 30, 0),
                         frequency: Duration::hours(2),
                         length: Duration::minutes(75),
                     },
                 ],
             },
-            MetaKey::TangledDepths => Meta {
+            MapMetaKind::TangledDepths => MapMeta {
                 name: "Tangled Depths".to_string(),
                 category: Category::HeartOfThorns,
                 schedules: vec![
@@ -508,7 +532,7 @@ impl MetaKey {
                     },
                 ],
             },
-            MetaKey::DragonsStand => Meta {
+            MapMetaKind::DragonsStand => MapMeta {
                 name: "Dragon's Stand".to_string(),
                 category: Category::HeartOfThorns,
                 schedules: vec![EventSchedule {
@@ -518,7 +542,7 @@ impl MetaKey {
                     length: Duration::hours(2),
                 }],
             },
-            MetaKey::LakeDoric => Meta {
+            MapMetaKind::LakeDoric => MapMeta {
                 name: "Lake Doric".to_string(),
                 category: Category::LivingWorldSeason3,
                 schedules: vec![
@@ -542,7 +566,7 @@ impl MetaKey {
                     },
                 ],
             },
-            MetaKey::CrystalOasis => Meta {
+            MapMetaKind::CrystalOasis => MapMeta {
                 name: "Crystal Oasis".to_string(),
                 category: Category::PathOfFire,
                 schedules: vec![
@@ -560,7 +584,7 @@ impl MetaKey {
                     },
                 ],
             },
-            MetaKey::DesertHighlands => Meta {
+            MapMetaKind::DesertHighlands => MapMeta {
                 name: "Desert Highlands".to_string(),
                 category: Category::PathOfFire,
                 schedules: vec![EventSchedule {
@@ -570,7 +594,7 @@ impl MetaKey {
                     length: Duration::minutes(20),
                 }],
             },
-            MetaKey::ElonRiverlands => Meta {
+            MapMetaKind::ElonRiverlands => MapMeta {
                 name: "Elon Riverlands".to_string(),
                 category: Category::PathOfFire,
                 schedules: vec![
@@ -588,7 +612,7 @@ impl MetaKey {
                     },
                 ],
             },
-            MetaKey::TheDesolation => Meta {
+            MapMetaKind::TheDesolation => MapMeta {
                 name: "The Desolation".to_string(),
                 category: Category::PathOfFire,
                 schedules: vec![
@@ -612,7 +636,7 @@ impl MetaKey {
                     },
                 ],
             },
-            MetaKey::DomainOfVabbi => Meta {
+            MapMetaKind::DomainOfVabbi => MapMeta {
                 name: "Domain of Vabbi".to_string(),
                 category: Category::PathOfFire,
                 schedules: vec![
@@ -630,7 +654,7 @@ impl MetaKey {
                     },
                 ],
             },
-            MetaKey::DomainOfIstan => Meta {
+            MapMetaKind::DomainOfIstan => MapMeta {
                 name: "Domain of Istan".to_string(),
                 category: Category::LivingWorldSeason4,
                 schedules: vec![EventSchedule {
@@ -640,7 +664,7 @@ impl MetaKey {
                     length: Duration::minutes(30),
                 }],
             },
-            MetaKey::JahaiBluffs => Meta {
+            MapMetaKind::JahaiBluffs => MapMeta {
                 name: "Jahai Bluffs".to_string(),
                 category: Category::LivingWorldSeason4,
                 schedules: vec![
@@ -658,7 +682,7 @@ impl MetaKey {
                     },
                 ],
             },
-            MetaKey::ThunderheadPeaks => Meta {
+            MapMetaKind::ThunderheadPeaks => MapMeta {
                 name: "Thunderhead Peaks".to_string(),
                 category: Category::LivingWorldSeason4,
                 schedules: vec![
@@ -676,7 +700,7 @@ impl MetaKey {
                     },
                 ],
             },
-            MetaKey::GrothmarValley => Meta {
+            MapMetaKind::GrothmarValley => MapMeta {
                 name: "Grothmar Valley".to_string(),
                 category: Category::TheIcebroodSaga,
                 schedules: vec![
@@ -706,7 +730,7 @@ impl MetaKey {
                     },
                 ],
             },
-            MetaKey::BjoraMarches => Meta {
+            MapMetaKind::BjoraMarches => MapMeta {
                 name: "Bjora Marches".to_string(),
                 category: Category::TheIcebroodSaga,
                 schedules: vec![
@@ -736,7 +760,7 @@ impl MetaKey {
                     },
                 ],
             },
-            MetaKey::Dragonstorm => Meta {
+            MapMetaKind::Dragonstorm => MapMeta {
                 name: "Dragonstorm".to_string(),
                 category: Category::TheIcebroodSaga,
                 schedules: vec![EventSchedule {
